==> zio-aws-databasemigration_2.12-5.17.128.1-sources.jar: zio/aws/databasemigration/model/RebootReplicationInstanceRequest.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databasemigration.model.primitives.BooleanOptional
import scala.jdk.CollectionConverters._
final case class RebootReplicationInstanceRequest(
    replicationInstanceArn: String,
    forceFailover: Option[BooleanOptional] = None,
    forcePlannedFailover: Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest = {
    import RebootReplicationInstanceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
      .builder()
      .replicationInstanceArn(replicationInstanceArn: java.lang.String)
      .optionallyWith(
        forceFailover.map(value =>
          BooleanOptional.unwrap(value): java.lang.Boolean
        )
      )(_.forceFailover)
      .optionallyWith(
        forcePlannedFailover.map(value =>
          BooleanOptional.unwrap(value): java.lang.Boolean
        )
      )(_.forcePlannedFailover)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly =
    zio.aws.databasemigration.model.RebootReplicationInstanceRequest
      .wrap(buildAwsValue())
}
object RebootReplicationInstanceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.RebootReplicationInstanceRequest =
      zio.aws.databasemigration.model.RebootReplicationInstanceRequest(
        replicationInstanceArn,
        forceFailover.map(value => value),
        forcePlannedFailover.map(value => value)
      )
    def replicationInstanceArn: String
    def forceFailover: Option[BooleanOptional]
    def forcePlannedFailover: Option[BooleanOptional]
    def getReplicationInstanceArn: ZIO[Any, Nothing, String] =
      ZIO.succeed(replicationInstanceArn)
    def getForceFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forceFailover", forceFailover)
    def getForcePlannedFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forcePlannedFailover", forcePlannedFailover)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ) extends zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly {
    override val replicationInstanceArn: String =
      impl.replicationInstanceArn(): String
    override val forceFailover: Option[BooleanOptional] = scala
      .Option(impl.forceFailover())
      .map(value =>
        zio.aws.databasemigration.model.primitives.BooleanOptional(value)
      )
    override val forcePlannedFailover: Option[BooleanOptional] = scala
      .Option(impl.forcePlannedFailover())
      .map(value =>
        zio.aws.databasemigration.model.primitives.BooleanOptional(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ): zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.12-5.17.147.1-sources.jar: zio/aws/databasemigration/model/RebootReplicationInstanceRequest.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databasemigration.model.primitives.BooleanOptional
import scala.jdk.CollectionConverters._
final case class RebootReplicationInstanceRequest(
    replicationInstanceArn: String,
    forceFailover: Option[BooleanOptional] = None,
    forcePlannedFailover: Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest = {
    import RebootReplicationInstanceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
      .builder()
      .replicationInstanceArn(replicationInstanceArn: java.lang.String)
      .optionallyWith(forceFailover.map(value => value: java.lang.Boolean))(
        _.forceFailover
      )
      .optionallyWith(
        forcePlannedFailover.map(value => value: java.lang.Boolean)
      )(_.forcePlannedFailover)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly =
    zio.aws.databasemigration.model.RebootReplicationInstanceRequest
      .wrap(buildAwsValue())
}
object RebootReplicationInstanceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.RebootReplicationInstanceRequest =
      zio.aws.databasemigration.model.RebootReplicationInstanceRequest(
        replicationInstanceArn,
        forceFailover.map(value => value),
        forcePlannedFailover.map(value => value)
      )
    def replicationInstanceArn: String
    def forceFailover: Option[BooleanOptional]
    def forcePlannedFailover: Option[BooleanOptional]
    def getReplicationInstanceArn: ZIO[Any, Nothing, String] =
      ZIO.succeed(replicationInstanceArn)
    def getForceFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forceFailover", forceFailover)
    def getForcePlannedFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forcePlannedFailover", forcePlannedFailover)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ) extends zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly {
    override val replicationInstanceArn: String =
      impl.replicationInstanceArn(): String
    override val forceFailover: Option[BooleanOptional] =
      scala.Option(impl.forceFailover()).map(value => value: BooleanOptional)
    override val forcePlannedFailover: Option[BooleanOptional] = scala
      .Option(impl.forcePlannedFailover())
      .map(value => value: BooleanOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.RebootReplicationInstanceRequest
  ): zio.aws.databasemigration.model.RebootReplicationInstanceRequest.ReadOnly =
    new Wrapper(impl)
}
